==> tdesdk-trinity_14.0.4.orig.tar.xz: tdesdk-trinity-14.0.4/kbabel/kbabeldict/modules/pocompendium/pc_factory.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.
	
**************************************************************************** */


#ifndef PC_FACTORY_H
#define PC_FACTORY_H

#include <klibloader.h>
class TDEInstance;
class TDEAboutData;

class PcFactory : public KLibFactory
{
	Q_OBJECT
  
public:
	PcFactory( TQObject *parent=0, const char *name=0);
	~PcFactory();

	virtual TQObject *createObject( TQObject *parent=0, const char *name=0
					, const char *classname=TQOBJECT_OBJECT_NAME_STRING
					, const TQStringList &args = TQStringList());

	static TDEInstance *instance();

private: 
	static TDEInstance *s_instance;
	static TDEAboutData *s_about;
};

#endif

==> tdesdk-trinity-14.1.5.tar.xz: tdesdk-trinity-14.1.5/kbabel/kbabeldict/modules/pocompendium/pc_factory.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.
	
**************************************************************************** */


#ifndef PC_FACTORY_H
#define PC_FACTORY_H

#include <klibloader.h>
class TDEInstance;
class TDEAboutData;

class PcFactory : public KLibFactory
{
	TQ_OBJECT
  
public:
	PcFactory( TQObject *parent=0, const char *name=0);
	~PcFactory();

	virtual TQObject *createObject( TQObject *parent=0, const char *name=0
					, const char *classname="TQObject"
					, const TQStringList &args = TQStringList());

	static TDEInstance *instance();

private: 
	static TDEInstance *s_instance;
	static TDEAboutData *s_about;
};

#endif
